#!/bin/sh
#------------------------------------------------------------------------------
# /tmp/preinstall.sh - pre installation file for archimap services on EIS/FAIR
#
# Copyright (c) 2002-2020  The Eisfair Team, team(at)eisfair(dot)org
#
# Creation:     2003-09-15  jed
# Last Update:  $Id: preinstall.sh 79042 2020-07-02 11:08:38Z jed $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version..
#------------------------------------------------------------------------------

pgmname=`basename $0`
module_name='mailx'

# extract shared library file from archive
# to be able to use the myecho command
archivefile=`find /tmp -maxdepth 1 -type l -name "${module_name}.tar.*" ! -name "*.info" | head -n1`

if [ -n "${archivefile}" ]
then
    if [ -s "${archivefile}" ]
    then
        tar xjf ${archivefile} var/install/include/jedlib.${module_name} -C /

        srcfile=/var/install/include/jedlib.${module_name}
        destfile=/var/install/include/jedlib

        if [ -f ${srcfile} ]
        then
            if [ -f ${destfile} ]
            then
                srcver=`/bin/sh ${srcfile} version`
                destver=`/bin/sh ${destfile} version`

                if [ -n "${destver}" ]
                then
                    # version number exists - compare version numbers
                    if [ `echo "${srcver} > ${destver}" | bc` -eq 1 ]
                    then
                        # update file
                        echo "updating shared library file (${destver}->${srcver}) ..."
                        mv -v ${srcfile} ${destfile}
                    fi
                else
                    # no version number exists - update file
                    echo "updating shared library file ..."
                    mv -v ${srcfile} ${destfile}
                fi
            else
                # file doesn't exist - update file
                echo "updating shared library file ..."
                mv -v ${srcfile} ${destfile}
            fi
        fi
    fi
fi

# read eislib etc.
. /var/install/include/eislib
. /var/install/include/jedlib

myecho --pack ${module_name} --info "running preinstall.sh ..."

exit 0
